import { DelFavoriteProductApi, DetailFavoriteProductApi, MoveFavoriteProductApi } from "@/api/favorite";
import { alert } from "@/common/common";
import { getFilterData } from "@/common/util";
import Product from "../components/product";
import Search from "@/components/search"
import { Text, View } from "@tarojs/components"
import Taro, { useRouter } from "@tarojs/taro";
import classnames from "classnames";
import { useCallback, useEffect, useMemo, useRef, useState } from "react";
import styles  from './index.module.scss'
import MCheckbox from "@/components/checkbox";
import AddCollection from "@/components/addCollection";


export default () => {

  const router = useRouter()

  //获取收藏夹面料
  const {fetchData: fetchDataDetailFavoriteProduct} = DetailFavoriteProductApi()
  const [colorInfo, setColorInfo] = useState<any>({})
  const getFavoriteInfo = async () => {
      let res = await fetchDataDetailFavoriteProduct(searchData)
      if(res.success) {
        Taro.setNavigationBarTitle({
          title: res.data.name
        })
        setColorInfo(res.data)
      }
  }

  //获取搜索数据
  const [searchData, setSearchData] = useState({id:0, key: ''})
  const onSearch = useCallback((e) => {
    setSearchData(() => e)
  }, [])
  useEffect(() => {
    let id = router.params.id || 0
    if(id) setSearchData((e) => ({...e, id: parseInt(id as string)}))
  }, [])

  useEffect(() => {
    if(searchData.id) getFavoriteInfo()
  }, [searchData])

  const productList = useMemo(() => {
    return colorInfo.product_color_list
  }, [colorInfo])

  
  //获取选中的id
  const [ids, setIds] = useState<number[]>([])
  const getSelectIds = useCallback((val) => {
    setIds(() => val)
  }, [])

  //全选反选
  const [allSelectStatus, setAllSelectStatus] = useState(false)
  const selectCallBack = useCallback(() => {
    setAllSelectStatus(() => true)
    setSelectStatus(1)
  }, [])
  const colseCallBack = useCallback(() => {
    setAllSelectStatus(() => false)
    setSelectStatus(3)
  }, [])

  const [selectStatus, setSelectStatus] = useState<1|2|3>(3)
  useEffect(() => {
    if(colorInfo.product_color_list?.length) {
      if(ids.length == colorInfo.product_color_list.length) {
        setSelectStatus(1)
        setAllSelectStatus(true)
      } else if ( 0 < ids.length && ids.length < colorInfo.product_color_list.length){
        setSelectStatus(2)
        setAllSelectStatus(false)
      } else {
        setSelectStatus(3)
        setAllSelectStatus(false)
      }
    }
  }, [ids, colorInfo]) 


  const [collectionShow, setCollectionShow] = useState(false)
  const closeCollection = useCallback(() => {
    setCollectionShow(false)
  }, [])

  //移动面料
  const {fetchData: fetchDataMoveFavoriteProduct} = MoveFavoriteProductApi()
  const onAdd = async () => {
    if(ids.length == 0) return alert.none('请选择要移动面料')
    let res = await fetchDataMoveFavoriteProduct({favorite_id: searchData.id, product_id:ids})
    if(res.success) {
      getFavoriteInfo()
      alert.success('修改成功')
    }
  }

  //取消收藏
  const {fetchData: delFavoriteProductFetchData} = DelFavoriteProductApi()
  const delCollectioin = async () => {
    if(ids.length == 0) return alert.none('请选择要取消面料')
    let res = await delFavoriteProductFetchData({favorite_id: searchData.id, product_id:ids})
    if(res.success) {
      getFavoriteInfo()
      alert.none('已取消收藏')
    }
  }

  return (
    <View className={styles.collection_main}>
      <View className={styles.search}>
        <Search  style={{width: '100%'}} debounceTime={300} changeOnSearch={onSearch} placeholder="请输入面料关键词" />
      </View>
      <View className={styles.operation}>
          <View className={styles.operation_check}>
            <MCheckbox status={allSelectStatus} onSelect={() => selectCallBack()} onClose={() => colseCallBack()}/>
            <Text className={styles.allSelect}>全选</Text>
          </View>
          <View className={styles.operation_check_right}>
            <Text className={styles.operation_check_move} onClick={() => setCollectionShow(true)}>移动到</Text>
            <Text className={styles.operation_check_cancel} onClick={delCollectioin}>取消收藏</Text>
          </View>
        </View>
      <View className={styles.class_list}>
        <Product productList={productList} onSelectIds={getSelectIds} selectStatus={selectStatus} openCheckBox={true}/>
      </View>
      <AddCollection show={collectionShow} onAdd={onAdd} onClose={closeCollection}/>
    </View>
  )
  }